@@ -18,10 +18,6 @@
 #include <my_global.h>
 #include "mysql_version.h"
 #include "spd_environ.h"
-#if MYSQL_VERSION_ID < 50500
-#include "mysql_priv.h"
-#include <mysql/plugin.h>
-#else
 #include "sql_priv.h"
 #include "probes_mysql.h"
 #include "sql_class.h"
@@ -29,7 +25,6 @@
 #include "sql_base.h"
 #include "sql_servers.h"
 #include "tztime.h"
-#endif
 #include "spd_err.h"
 #include "spd_param.h"
 #include "spd_db_include.h"
@@ -44,9 +39,7 @@
 #include "spd_udf.h"
 #include "spd_malloc.h"
 
-#if defined(MARIADB_BASE_VERSION) && MYSQL_VERSION_ID >= 100004
 #define SPIDER_NEED_INIT_ONE_TABLE_FOR_FIND_TEMPORARY_TABLE
-#endif
 
 extern const char **spd_defaults_extra_file;
 extern const char **spd_defaults_file;
@@ -115,21 +108,6 @@ int spider_udf_direct_sql_create_table_list(
     } else
       break;
   }
-#if MYSQL_VERSION_ID < 50500
-  if (!(direct_sql->db_names = (char**)
-    spider_bulk_malloc(spider_current_trx, 31, MYF(MY_WME | MY_ZEROFILL),
-      &direct_sql->db_names, (uint) (sizeof(char*) * table_count),
-      &direct_sql->table_names, (uint) (sizeof(char*) * table_count),
-      &direct_sql->tables, (uint) (sizeof(TABLE*) * table_count),
-      &tmp_name_ptr, (uint) (sizeof(char) * (
-        table_name_list_length +
-        thd->db_length * table_count +
-        2 * table_count
-      )),
-      &direct_sql->iop, (uint) (sizeof(int) * table_count),
-      NullS))
-  )
-#else
   if (!(direct_sql->db_names = (char**)
     spider_bulk_malloc(spider_current_trx, 31, MYF(MY_WME | MY_ZEROFILL),
       &direct_sql->db_names, (uint) (sizeof(char*) * table_count),
@@ -146,7 +124,6 @@ int spider_udf_direct_sql_create_table_list(
         (uint) (sizeof(uchar) * ((table_count + 7) / 8)),
       NullS))
   )
-#endif
     DBUG_RETURN(HA_ERR_OUT_OF_MEM);
 
   tmp_ptr = table_name_list;
@@ -382,10 +359,8 @@ int spider_udf_direct_sql_create_conn_key(
       tmp_name = strmov(tmp_name + 1, direct_sql->tgt_driver);
     } else
       tmp_name++;
-#ifdef SPIDER_HAS_HASH_VALUE_TYPE
   direct_sql->conn_key_hash_value = my_calc_hash(&spider_open_connections,
     (uchar*) direct_sql->conn_key, direct_sql->conn_key_length);
-#endif
   DBUG_RETURN(0);
 }
 
@@ -578,12 +553,8 @@ SPIDER_CONN *spider_udf_direct_sql_create_conn(
   conn->semi_trx_chk = FALSE;
     conn->conn_kind = SPIDER_CONN_KIND_MYSQL;
 
-#if MYSQL_VERSION_ID < 50500
-  if (pthread_mutex_init(&conn->mta_conn_mutex, MY_MUTEX_INIT_FAST))
-#else
   if (mysql_mutex_init(spd_key_mutex_mta_conn, &conn->mta_conn_mutex,
     MY_MUTEX_INIT_FAST))
-#endif
   {
     *error_num = HA_ERR_OUT_OF_MEM;
     goto error_mta_conn_mutex_init;
@@ -604,14 +575,9 @@ SPIDER_CONN *spider_udf_direct_sql_create_conn(
   pthread_mutex_unlock(&spider_conn_id_mutex);
 
   pthread_mutex_lock(&spider_ipport_conn_mutex);
-#ifdef SPIDER_HAS_HASH_VALUE_TYPE
   if ((ip_port_conn = (SPIDER_IP_PORT_CONN*) my_hash_search_using_hash_value(
     &spider_ipport_conns, conn->conn_key_hash_value,
     (uchar*)conn->conn_key, conn->conn_key_length)))
-#else
-  if ((ip_port_conn = (SPIDER_IP_PORT_CONN*) my_hash_search(
-    &spider_ipport_conns, (uchar*)conn->conn_key, conn->conn_key_length)))
-#endif
   { /* exists, +1 */
     pthread_mutex_unlock(&spider_ipport_conn_mutex);
     pthread_mutex_lock(&ip_port_conn->mutex);
@@ -668,18 +634,11 @@ SPIDER_CONN *spider_udf_direct_sql_get_conn(
   SPIDER_CONN *conn = NULL;
   DBUG_ENTER("spider_udf_direct_sql_get_conn");
 
-#ifdef SPIDER_HAS_HASH_VALUE_TYPE
   if (
       !(conn = (SPIDER_CONN*) my_hash_search_using_hash_value(
         &trx->trx_conn_hash, direct_sql->conn_key_hash_value,
         (uchar*) direct_sql->conn_key, direct_sql->conn_key_length))
   )
-#else
-  if (
-      !(conn = (SPIDER_CONN*) my_hash_search(&trx->trx_conn_hash,
-          (uchar*) direct_sql->conn_key, direct_sql->conn_key_length))
-  )
-#endif
   {
     if (
         (
@@ -688,14 +647,9 @@ SPIDER_CONN *spider_udf_direct_sql_get_conn(
         )
     ) {
         pthread_mutex_lock(&spider_conn_mutex);
-#ifdef SPIDER_HAS_HASH_VALUE_TYPE
         if (!(conn = (SPIDER_CONN*) my_hash_search_using_hash_value(
           &spider_open_connections, direct_sql->conn_key_hash_value,
           (uchar*) direct_sql->conn_key, direct_sql->conn_key_length)))
-#else
-        if (!(conn = (SPIDER_CONN*) my_hash_search(&spider_open_connections,
-          (uchar*) direct_sql->conn_key, direct_sql->conn_key_length)))
-#endif
         {
           pthread_mutex_unlock(&spider_conn_mutex);
           DBUG_PRINT("info",("spider create new conn"));
@@ -703,12 +657,7 @@ SPIDER_CONN *spider_udf_direct_sql_get_conn(
             error_num)))
             goto error;
         } else {
-#ifdef HASH_UPDATE_WITH_HASH_VALUE
-          my_hash_delete_with_hash_value(&spider_open_connections,
-            conn->conn_key_hash_value, (uchar*) conn);
-#else
           my_hash_delete(&spider_open_connections, (uchar*) conn);
-#endif
           pthread_mutex_unlock(&spider_conn_mutex);
           DBUG_PRINT("info",("spider get global conn"));
         }
@@ -722,12 +671,7 @@ SPIDER_CONN *spider_udf_direct_sql_get_conn(
     conn->priority = direct_sql->priority;
 
       uint old_elements = trx->trx_conn_hash.array.max_element;
-#ifdef HASH_UPDATE_WITH_HASH_VALUE
-      if (my_hash_insert_with_hash_value(&trx->trx_conn_hash,
-        direct_sql->conn_key_hash_value, (uchar*) conn))
-#else
       if (my_hash_insert(&trx->trx_conn_hash, (uchar*) conn))
-#endif
       {
         spider_free_conn(conn);
         *error_num = HA_ERR_OUT_OF_MEM;
@@ -1025,10 +969,7 @@ int spider_udf_parse_direct_sql_param(
   direct_sql->net_write_timeout = -1;
   direct_sql->bulk_insert_rows = -1;
   direct_sql->connection_channel = -1;
-#if MYSQL_VERSION_ID < 50500
-#else
   direct_sql->use_real_table = -1;
-#endif
   direct_sql->error_rw_mode = -1;
   for (roop_count = 0; roop_count < direct_sql->table_count; roop_count++)
     direct_sql->iop[roop_count] = -1;
@@ -1102,10 +1043,7 @@ int spider_udf_parse_direct_sql_param(
         SPIDER_PARAM_STR("srv", server_name);
         SPIDER_PARAM_INT_WITH_MAX("svc", tgt_ssl_vsc, 0, 1);
         SPIDER_PARAM_INT_WITH_MAX("tlm", table_loop_mode, 0, 2);
-#if MYSQL_VERSION_ID < 50500
-#else
         SPIDER_PARAM_INT_WITH_MAX("urt", use_real_table, 0, 1);
-#endif
         SPIDER_PARAM_INT("wto", net_write_timeout, 0);
         error_num = param_string_parse.print_param_error();
         goto error;
@@ -1155,10 +1093,7 @@ int spider_udf_parse_direct_sql_param(
         error_num = param_string_parse.print_param_error();
         goto error;
       case 14:
-#if MYSQL_VERSION_ID < 50500
-#else
         SPIDER_PARAM_INT_WITH_MAX("use_real_table", use_real_table, 0, 1);
-#endif
         error_num = param_string_parse.print_param_error();
         goto error;
       case 15:
@@ -1445,11 +1380,8 @@ int spider_udf_set_direct_sql_param_default(
     direct_sql->bulk_insert_rows = 3000;
   if (direct_sql->connection_channel == -1)
     direct_sql->connection_channel = 0;
-#if MYSQL_VERSION_ID < 50500
-#else
   if (direct_sql->use_real_table == -1)
     direct_sql->use_real_table = 0;
-#endif
   if (direct_sql->error_rw_mode == -1)
     direct_sql->error_rw_mode = 0;
   for (roop_count = 0; roop_count < direct_sql->table_count; roop_count++)
@@ -1466,7 +1398,6 @@ void spider_udf_free_direct_sql_alloc(
 ) {
   SPIDER_BG_DIRECT_SQL *bg_direct_sql;
   DBUG_ENTER("spider_udf_free_direct_sql_alloc");
-#ifndef WITHOUT_SPIDER_BG_SEARCH
   if (bg)
   {
     pthread_mutex_lock(direct_sql->bg_mutex);
@@ -1480,15 +1411,11 @@ void spider_udf_free_direct_sql_alloc(
     pthread_cond_signal(direct_sql->bg_cond);
     pthread_mutex_unlock(direct_sql->bg_mutex);
   }
-#endif
-#if MYSQL_VERSION_ID < 50500
-#else
   if (direct_sql->real_table_used && direct_sql->open_tables_thd)
   {
     spider_sys_close_table(direct_sql->open_tables_thd,
       &direct_sql->open_tables_backup);
   }
-#endif
   if (direct_sql->server_name)
   {
     spider_free(spider_current_trx, direct_sql->server_name, MYF(0));
@@ -1584,11 +1511,8 @@ long long spider_direct_sql_body(
   char *sql;
   TABLE_LIST table_list;
   SPIDER_BG_DIRECT_SQL *bg_direct_sql;
-#if MYSQL_VERSION_ID < 50500
-#else
   TABLE_LIST *real_table_list_last = NULL;
   uint use_real_table = 0;
-#endif
   DBUG_ENTER("spider_direct_sql_body");
   SPIDER_BACKUP_DASTATUS;
   if (!(direct_sql = (SPIDER_DIRECT_SQL *)
@@ -1601,7 +1525,6 @@ long long spider_direct_sql_body(
     my_error(ER_OUT_OF_RESOURCES, MYF(0), HA_ERR_OUT_OF_MEM);
     goto error;
   }
-#ifndef WITHOUT_SPIDER_BG_SEARCH
   if (bg)
   {
     bg_direct_sql = (SPIDER_BG_DIRECT_SQL *) initid->ptr;
@@ -1619,7 +1542,6 @@ long long spider_direct_sql_body(
     direct_sql->parent = bg_direct_sql;
     bg_direct_sql->called_cnt++;
   }
-#endif
   if (!(trx = spider_get_trx(thd, TRUE, &error_num)))
   {
     if (error_num == HA_ERR_OUT_OF_MEM)
@@ -1672,11 +1594,8 @@ long long spider_direct_sql_body(
   }
     trx->updated_in_this_trx = TRUE;
     DBUG_PRINT("info",("spider trx->updated_in_this_trx=TRUE"));
-#if MYSQL_VERSION_ID < 50500
-#else
   use_real_table = spider_param_udf_ds_use_real_table(thd,
     direct_sql->use_real_table);
-#endif
   for (roop_count = 0; roop_count < direct_sql->table_count; roop_count++)
   {
 #ifdef SPIDER_NEED_INIT_ONE_TABLE_FOR_FIND_TEMPORARY_TABLE
@@ -1707,19 +1626,14 @@ long long spider_direct_sql_body(
     if (!(direct_sql->tables[roop_count] =
       spider_find_temporary_table(thd, &table_list)))
     {
-#if MYSQL_VERSION_ID < 50500
-#else
       if (!use_real_table)
       {
-#endif
         error_num = ER_SPIDER_UDF_TMP_TABLE_NOT_FOUND_NUM;
         my_printf_error(ER_SPIDER_UDF_TMP_TABLE_NOT_FOUND_NUM,
           ER_SPIDER_UDF_TMP_TABLE_NOT_FOUND_STR,
           MYF(0), SPIDER_TABLE_LIST_db_str(&table_list),
           SPIDER_TABLE_LIST_table_name_str(&table_list));
         goto error;
-#if MYSQL_VERSION_ID < 50500
-#else
       }
       TABLE_LIST *tables = &direct_sql->table_list[roop_count];
 #ifdef SPIDER_use_LEX_CSTRING_for_database_tablename_alias
@@ -1746,7 +1660,6 @@ long long spider_direct_sql_body(
       real_table_list_last = tables;
       spider_set_bit(direct_sql->real_table_bitmap, roop_count);
       direct_sql->real_table_used = TRUE;
-#endif
     }
   }
   if ((error_num = spider_udf_direct_sql_create_conn_key(direct_sql)))
@@ -1777,7 +1690,6 @@ long long spider_direct_sql_body(
     direct_sql->sql_length = 0;
   direct_sql->sql = sql;
 
-#ifndef WITHOUT_SPIDER_BG_SEARCH
   if (bg)
   {
     if ((error_num = spider_udf_bg_direct_sql(direct_sql)))
@@ -1787,7 +1699,6 @@ long long spider_direct_sql_body(
       goto error;
     }
   } else {
-#endif
     if (conn->bg_init)
       pthread_mutex_lock(&conn->bg_conn_mutex);
     if ((error_num = spider_db_udf_direct_sql(direct_sql)))
@@ -1804,15 +1715,11 @@ long long spider_direct_sql_body(
       pthread_mutex_unlock(&conn->bg_conn_mutex);
     if (direct_sql->modified_non_trans_table)
       thd->transaction->stmt.modified_non_trans_table = TRUE;
-#ifndef WITHOUT_SPIDER_BG_SEARCH
   }
   if (!bg)
   {
-#endif
     spider_udf_free_direct_sql_alloc(direct_sql, FALSE);
-#ifndef WITHOUT_SPIDER_BG_SEARCH
   }
-#endif
   DBUG_RETURN(1);
 
 error:
@@ -1853,7 +1760,6 @@ my_bool spider_direct_sql_init_body(
     strcpy(message, "spider_(bg)_direct_sql() requires string arguments");
     goto error;
   }
-#ifndef WITHOUT_SPIDER_BG_SEARCH
   if (bg)
   {
     if (!(bg_direct_sql = (SPIDER_BG_DIRECT_SQL *)
@@ -1863,37 +1769,26 @@ my_bool spider_direct_sql_init_body(
       strcpy(message, "spider_bg_direct_sql() out of memory");
       goto error;
     }
-#if MYSQL_VERSION_ID < 50500
-    if (pthread_mutex_init(&bg_direct_sql->bg_mutex, MY_MUTEX_INIT_FAST))
-#else
     if (mysql_mutex_init(spd_key_mutex_bg_direct_sql,
       &bg_direct_sql->bg_mutex, MY_MUTEX_INIT_FAST))
-#endif
     {
       strcpy(message, "spider_bg_direct_sql() out of memory");
       goto error_mutex_init;
     }
-#if MYSQL_VERSION_ID < 50500
-    if (pthread_cond_init(&bg_direct_sql->bg_cond, NULL))
-#else
     if (mysql_cond_init(spd_key_cond_bg_direct_sql,
       &bg_direct_sql->bg_cond, NULL))
-#endif
     {
       strcpy(message, "spider_bg_direct_sql() out of memory");
       goto error_cond_init;
     }
     initid->ptr = (char *) bg_direct_sql;
   }
-#endif
   DBUG_RETURN(FALSE);
 
-#ifndef WITHOUT_SPIDER_BG_SEARCH
 error_cond_init:
   pthread_mutex_destroy(&bg_direct_sql->bg_mutex);
 error_mutex_init:
   spider_free(spider_current_trx, bg_direct_sql, MYF(0));
-#endif
 error:
   DBUG_RETURN(TRUE);
 }
@@ -1921,7 +1816,6 @@ void spider_direct_sql_deinit_body(
   DBUG_VOID_RETURN;
 }
 
-#ifndef WITHOUT_SPIDER_BG_SEARCH
 void spider_direct_sql_bg_start(
   UDF_INIT *initid
 ) {
@@ -2010,4 +1904,3 @@ int spider_udf_bg_direct_sql(
   }
   DBUG_RETURN(0);
 }
-#endif
