@@ -138,8 +138,8 @@ static MYSQL_SYSVAR_BOOL(
   TRUE
 );
 
-static void spider_use_table_value_deprecated(THD *thd, st_mysql_sys_var *,
-                                              void *var_ptr, const void *save)
+static void spider_var_deprecated_int(THD *thd, st_mysql_sys_var *,
+                                      void *var_ptr, const void *save)
 {
   int val= *static_cast<const int *>(save);
   *static_cast<int *>(var_ptr)= val;
@@ -152,6 +152,20 @@ static void spider_use_table_value_deprecated(THD *thd, st_mysql_sys_var *,
   }
 }
 
+static void spider_var_deprecated_longlong(THD *thd, st_mysql_sys_var *,
+                                           void *var_ptr, const void *save)
+{
+  longlong val= *static_cast<const longlong *>(save);
+  *static_cast<longlong *>(var_ptr)= val;
+  if (val == -1)
+  {
+    push_warning_printf(thd, Sql_condition::WARN_LEVEL_WARN,
+                        HA_ERR_UNSUPPORTED,
+                        "The option value -1 (use table value) is deprecated "
+                        "and will be removed in a future release");
+  }
+}
+
 my_bool spider_param_support_xa()
 {
   DBUG_ENTER("spider_param_support_xa");
@@ -233,7 +247,7 @@ static MYSQL_SYSVAR_INT(
   PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_READONLY,
   "Use table charset for remote access",
   NULL,
-  spider_use_table_value_deprecated,
+  spider_var_deprecated_int,
   1,
   -1,
   1,
@@ -436,7 +450,7 @@ static MYSQL_THDVAR_LONGLONG(
   PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED, /* opt */
   "Internal offset", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_longlong, /* update */
   0, /* def */
   -1, /* min */
   9223372036854775807LL, /* max */
@@ -461,7 +475,7 @@ static MYSQL_THDVAR_LONGLONG(
   PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED, /* opt */
   "Internal limit", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_longlong, /* update */
   9223372036854775807LL, /* def */
   -1, /* min */
   9223372036854775807LL, /* max */
@@ -486,7 +500,7 @@ static MYSQL_THDVAR_LONGLONG(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Number of rows at a select", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_longlong, /* update */
   9223372036854775807LL, /* def */
   -1, /* min */
   9223372036854775807LL, /* max */
@@ -512,7 +526,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Use offset and limit parameter in SQL for split_read parameter.", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   2, /* def */
   -1, /* min */
   2147483647, /* max */
@@ -537,7 +551,7 @@ static MYSQL_THDVAR_LONGLONG(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "The limit value for semi_split_read", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_longlong, /* update */
   9223372036854775807LL, /* def */
   -1, /* min */
   9223372036854775807LL, /* max */
@@ -560,10 +574,10 @@ longlong spider_param_semi_split_read_limit(
  */
 static MYSQL_THDVAR_INT(
   init_sql_alloc_size, /* name */
-  PLUGIN_VAR_RQCMDARG, /* opt */
+  PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED, /* opt */
   "Initial sql string alloc size", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   1024, /* def */
   -1, /* min */
   2147483647, /* max */
@@ -589,7 +603,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Reset sql string alloc after execute", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   1, /* def */
   -1, /* min */
   1, /* max */
@@ -615,7 +629,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Sprit read mode for multi range", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   100, /* def */
   -1, /* min */
   2147483647, /* max */
@@ -640,7 +654,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Max columns for order by", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   32767, /* def */
   -1, /* min */
   32767, /* max */
@@ -723,11 +737,11 @@ static int spider_param_semi_table_lock_check(
  */
 static MYSQL_THDVAR_INT(
   semi_table_lock, /* name */
-  PLUGIN_VAR_RQCMDARG, /* opt */
+  PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED, /* opt */
   "Table lock during execute a sql", /* comment */
   &spider_param_semi_table_lock_check, /* check */
   NULL, /* update */
-  1, /* def */
+  0, /* def */
   0, /* min */
   1, /* max */
   0 /* blk */
@@ -783,10 +797,10 @@ static int spider_param_semi_table_lock_connection_check(
  */
 static MYSQL_THDVAR_INT(
   semi_table_lock_connection, /* name */
-  PLUGIN_VAR_RQCMDARG, /* opt */
+  PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED, /* opt */
   "Use different connection if semi_table_lock is enabled", /* comment */
   &spider_param_semi_table_lock_connection_check, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   1, /* def */
   -1, /* min */
   1, /* max */
@@ -835,7 +849,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Lock for select with update", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   1, /* def */
   -1, /* min */
   2, /* max */
@@ -924,7 +938,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Bulk insert size", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   16000, /* def */
   -1, /* min */
   2147483647, /* max */
@@ -953,7 +967,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "The mode of bulk updating and deleting", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   2, /* max */
@@ -978,7 +992,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Bulk update size", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   16000, /* def */
   -1, /* min */
   2147483647, /* max */
@@ -1000,10 +1014,10 @@ int spider_param_bulk_update_size(
  */
 static MYSQL_THDVAR_INT(
   buffer_size, /* name */
-  PLUGIN_VAR_RQCMDARG, /* opt */
+  PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED, /* opt */
   "Buffer size", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   16000, /* def */
   -1, /* min */
   2147483647, /* max */
@@ -1029,7 +1043,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Execute optimize to remote server", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   1, /* max */
@@ -1055,7 +1069,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Execute optimize to remote server with local", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   1, /* max */
@@ -1204,7 +1218,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Wait timeout of connecting to remote server", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   6, /* def */
   -1, /* min */
   2147483647, /* max */
@@ -1231,7 +1245,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Wait timeout of receiving data from remote server", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   600, /* def */
   -1, /* min */
   2147483647, /* max */
@@ -1258,7 +1272,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Wait timeout of sending data to remote server", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   600, /* def */
   -1, /* min */
   2147483647, /* max */
@@ -1289,7 +1303,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "The retrieval result from a remote server is acquired by acquisition one by one", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   3, /* def */
   -1, /* min */
   3, /* max */
@@ -1314,7 +1328,7 @@ static MYSQL_THDVAR_LONGLONG(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Number of records in a page when acquisition one by one", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   1024, /* def */
   -1, /* min */
   9223372036854775807LL, /* max */
@@ -1339,7 +1353,7 @@ static MYSQL_THDVAR_LONGLONG(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "The limitation of memory size in a page when acquisition one by one", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   10485760, /* def */
   -1, /* min */
   9223372036854775807LL, /* max */
@@ -1365,7 +1379,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Use low memory mode when SQL(SELECT) internally issued to a remote server is executed and get a result list", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   1, /* def */
   -1, /* min */
   1, /* max */
@@ -1392,7 +1406,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "The mode of using columns at select clause", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   1, /* def */
   -1, /* min */
   1, /* max */
@@ -1420,7 +1434,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Mode of background search", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   3, /* max */
@@ -1446,7 +1460,7 @@ static MYSQL_THDVAR_LONGLONG(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Number of first read records when background search is used", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   2, /* def */
   -1, /* min */
   9223372036854775807LL, /* max */
@@ -1472,7 +1486,7 @@ static MYSQL_THDVAR_LONGLONG(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Number of second read records when background search is used", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   100, /* def */
   -1, /* min */
   9223372036854775807LL, /* max */
@@ -1498,7 +1512,7 @@ static MYSQL_THDVAR_LONGLONG(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Number of first read records", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   9223372036854775807LL, /* max */
@@ -1524,7 +1538,7 @@ static MYSQL_THDVAR_LONGLONG(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Number of second read records", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   9223372036854775807LL, /* max */
@@ -1550,7 +1564,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Interval of cardinality confirmation.(second)", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   51, /* def */
   -1, /* min */
   2147483647, /* max */
@@ -1578,7 +1592,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED, /* opt */
   "Mode of cardinality confirmation.", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   1, /* def */
   -1, /* min */
   3, /* max */
@@ -1606,7 +1620,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Cardinality synchronization in partitioned table.", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   2, /* max */
@@ -1633,7 +1647,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED, /* opt */
   "Type of cardinality calculation.", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   2, /* def */
   -1, /* min */
   2, /* max */
@@ -1658,7 +1672,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED, /* opt */
   "Weight coefficient to calculate effectiveness of index from cardinality of column.", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   2, /* def */
   -1, /* min */
   2147483647, /* max */
@@ -1685,7 +1699,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Mode of cardinality confirmation at background.", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   2, /* def */
   -1, /* min */
   2, /* max */
@@ -1711,7 +1725,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Interval of table state confirmation.(second)", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   10, /* def */
   -1, /* min */
   2147483647, /* max */
@@ -1738,7 +1752,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED, /* opt */
   "Mode of table state confirmation.", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   1, /* def */
   -1, /* min */
   2, /* max */
@@ -1766,7 +1780,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Table state synchronization in partitioned table.", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   2, /* max */
@@ -1793,7 +1807,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Mode of table state confirmation at background.", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   2, /* def */
   -1, /* min */
   2, /* max */
@@ -1843,7 +1857,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Mode of auto increment.", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   3, /* max */
@@ -1936,7 +1950,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Execute \"REPLACE\" and \"INSERT IGNORE\" on remote server and avoid duplicate check on local server", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   1, /* max */
@@ -2265,7 +2279,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Mode of BKA for Spider", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   1, /* def */
   -1, /* min */
   2, /* max */
@@ -2343,7 +2357,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED, /* opt */
   "Use handler for reading", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   3, /* max */
@@ -2369,7 +2383,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Read error mode if error", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   1, /* max */
@@ -2395,7 +2409,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Write error mode if error", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   1, /* max */
@@ -2421,7 +2435,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Skip generating internal default condition", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   1, /* max */
@@ -2449,7 +2463,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Skip parallel search by specific conditions", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   3, /* max */
@@ -2475,7 +2489,7 @@ static MYSQL_THDVAR_LONGLONG(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Send 'ORDER BY' and 'LIMIT' to remote server directly", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   9223372036854775807LL, /* def */
   -1, /* min */
   9223372036854775807LL, /* max */
@@ -2501,7 +2515,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Read only", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   1, /* max */
@@ -2674,17 +2688,6 @@ uint spider_param_log_result_error_with_sql()
   DBUG_RETURN(spider_log_result_error_with_sql);
 }
 
-static char *spider_version = (char *) SPIDER_DETAIL_VERSION;
-static MYSQL_SYSVAR_STR(
-  version,
-  spider_version,
-  PLUGIN_VAR_NOCMDOPT | PLUGIN_VAR_READONLY,
-  "The version of Spider",
-  NULL,
-  NULL,
-  SPIDER_DETAIL_VERSION
-);
-
 /*
   0: server_id + thread_id
   1: server_id + thread_id + query_id
@@ -2719,7 +2722,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Read casually if it is possible", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   63, /* max */
@@ -2762,7 +2765,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "The type of delete_all_rows", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   1, /* def */
   -1, /* min */
   1, /* max */
@@ -2785,10 +2788,10 @@ int spider_param_delete_all_rows_type(
  */
 static MYSQL_THDVAR_INT(
   bka_table_name_type, /* name */
-  PLUGIN_VAR_RQCMDARG, /* opt */
+  PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED, /* opt */
   "The type of temporary table name for bka", /* comment */
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   0, /* def */
   -1, /* min */
   1, /* max */
@@ -2840,7 +2843,7 @@ static MYSQL_SYSVAR_INT(
   PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED,
   "Store last sts result into system table",
   NULL,
-  spider_use_table_value_deprecated,
+  spider_var_deprecated_int,
   1,
   -1,
   1,
@@ -2867,7 +2870,7 @@ static MYSQL_SYSVAR_INT(
   PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED,
   "Store last crd result into system table",
   NULL,
-  spider_use_table_value_deprecated,
+  spider_var_deprecated_int,
   1,
   -1,
   1,
@@ -2894,7 +2897,7 @@ static MYSQL_SYSVAR_INT(
   PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED,
   "Load sts from system table at startup",
   NULL,
-  spider_use_table_value_deprecated,
+  spider_var_deprecated_int,
   1,
   -1,
   1,
@@ -2921,7 +2924,7 @@ static MYSQL_SYSVAR_INT(
   PLUGIN_VAR_RQCMDARG | PLUGIN_VAR_DEPRECATED,
   "Load crd from system table at startup",
   NULL,
-  spider_use_table_value_deprecated,
+  spider_var_deprecated_int,
   1,
   -1,
   1,
@@ -3089,7 +3092,7 @@ static MYSQL_THDVAR_INT(
   PLUGIN_VAR_RQCMDARG, /* opt */
   "Use columns in select clause strictly for group by clause",
   NULL, /* check */
-  spider_use_table_value_deprecated, /* update */
+  spider_var_deprecated_int, /* update */
   1, /* def */
   -1, /* min */
   1, /* max */
@@ -3213,7 +3216,6 @@ static struct st_mysql_sys_var* spider_system_variables[] = {
   MYSQL_SYSVAR(conn_wait_timeout),
   MYSQL_SYSVAR(log_result_errors),
   MYSQL_SYSVAR(log_result_error_with_sql),
-  MYSQL_SYSVAR(version),
   MYSQL_SYSVAR(internal_xa_id_type),
   MYSQL_SYSVAR(casual_read),
   MYSQL_SYSVAR(dry_access),
